@@ -27,14 +27,14 @@ from beeswarm.drones.client.baits.clientbase import ClientBase
 logger = logging.getLogger(__name__)
 
 
-class smtp(ClientBase):
-    def __init__(self, sessions, options):
+class Smtp(ClientBase):
+    def __init__(self, options):
         """
             Initializes common values.
         :param sessions: A dict which is updated every time a new session is created.
         :param options: A dict containing all options
         """
-        super(smtp, self).__init__(sessions, options)
+        super(Smtp, self).__init__(options)
         self.client = None
         self.sent_mails = 0
         self.max_mails = random.randint(1, 4)
@@ -93,6 +93,7 @@ class smtp(ClientBase):
         finally:
             logger.debug('SMTP Session complete.')
             session.alldone = True
+            session.end_session()
 
     def get_one_mail(self):
         """
