@@ -1,3 +1,4 @@
+# pylint: ignored-modules=zmq,zmq.green
 # Copyright (C) 2014 Johnny Vestergaard <jkv@unixcluster.dk>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -116,7 +117,7 @@ class Drone(object):
             self.config = json.load(config_file, object_hook=asciify)
 
         mode = None
-        if self.config['general']['mode'] == '' or self.config['general']['mode'] == None:
+        if self.config['general']['mode'] == '' or self.config['general']['mode'] is None:
             logger.info('Drone has not been configured, awaiting configuration from Beeswarm server.')
         elif self.config['general']['mode'] == 'honeypot':
             mode = Honeypot
@@ -127,7 +128,7 @@ class Drone(object):
             self.drone = mode(self.work_dir, self.config)
             self.drone_greenlet = gevent.spawn(self.drone.start)
             self.drone_greenlet.link_exception(self.on_exception)
-            logger.info('Drone configured and running'.format(self.id))
+            logger.info('Drone configured and running. ({0})'.format(self.id))
 
     def stop(self):
         """Stops services"""
@@ -256,7 +257,6 @@ class Drone(object):
             if len(socks) > 0:
                 data = recv_monitor_message(monitor_socket)
                 event = data['event']
-                value = data['value']
                 if event == zmq.EVENT_CONNECTED:
                     logger.info('Connected to {0}'.format(log_name))
                     # always ask for config to avoid race condition.
