@@ -27,6 +27,9 @@ from smtpd import NEWLINE, EMPTYSTRING
 
 from beeswarm.drones.honeypot.capabilities.handlerbase import HandlerBase
 
+logger = logging.getLogger(__name__)
+
+
 
 class SMTPChannel(smtpd.SMTPChannel):
     def __init__(self, smtp_server, newsocket, fromaddr,
@@ -199,9 +202,7 @@ class SMTPChannel(smtpd.SMTPChannel):
     # support for AUTH is added.
     def found_terminator(self):
         line = EMPTYSTRING.join(self.__line)
-
-        if self.debug:
-            self.logger.info('found_terminator(): data: %s' % repr(line))
+        logger.debug('found_terminator(): data: {0}'.format(repr(line)))
 
         self.__line = []
         if self.__state == self.COMMAND:
@@ -281,20 +282,20 @@ class DummySMTPServer(object):
 
 
 class smtp(HandlerBase):
-    def __init__(self, sessions, options, work_dir):
-        super(smtp, self).__init__(sessions, options, work_dir)
+    def __init__(self, options, work_dir):
+        super(smtp, self).__init__(options, work_dir)
         self._options = options
 
     def handle_session(self, gsocket, address):
-        session_ = self.create_session(address)
-        local_map = {}
-        server = DummySMTPServer(self.vfsystem.opendir('/var/mail'))
-        SMTPChannel(server, gsocket, address, session=session_,
-                    smtp_map=local_map, opts=self._options)
+        session = self.create_session(address)
         try:
+            local_map = {}
+            server = DummySMTPServer(self.vfsystem.opendir('/var/mail'))
+            SMTPChannel(server, gsocket, address, session=session,
+                        smtp_map=local_map, opts=self._options)
             asyncore.loop(map=local_map)
         except Exception:
             # im sooooo evil!
             pass
         finally:
-            session_.connected = False
+            self.close_session(session)
